perform_scan

Function perform_scan 

pub unsafe extern "C" fn perform_scan(
    handle: ClientHandle,
    info: *mut ScanResultListInfo,
) -> Error
Available on non-ag35 only.
Performs a network scan and gets the list of available networks.

Implementation notes

Calls:

  • ql_log_print
  • mcm_client_execute_command_sync
    • Request type: mcm_nw_scan_req_msg_v01
    • Response type: mcm_nw_scan_resp_msg_v01

Uses a heap allocation for the mcm_nw_scan_resp_msg_v01 response before copying the data into the info parameter.