Struct CdmaInfo
#[repr(C)]pub struct CdmaInfo {
pub sid: u16,
pub nid: u16,
pub bid: u16,
pub refpn: u16,
pub base_lat: u32,
pub base_long: u32,
}Fields
sid: u16System ID.
nid: u16Network ID.
bid: u16Base station ID.
refpn: u16Reference pilot number.
base_lat: u32Latitude of the current base station in units of 0.25 sec.
base_long: u32Longitude of the current base station in units of 0.25 sec.