Struct IndicationFlag
#[repr(transparent)]pub struct IndicationFlag(<IndicationFlag as PublicFlags>::Internal);Expand description
Indication event flags for event_register.
Tuple Fields
0: <IndicationFlag as PublicFlags>::InternalImplementations
impl IndicationFlag
impl IndicationFlag
pub const VOICE_REG_EVENT: Self
pub const VOICE_REG_EVENT: Self
Voice registration indication.
pub const DATA_REG_EVENT: Self
pub const DATA_REG_EVENT: Self
Data registration indication.
pub const SIGNAL_STRENGTH_EVENT: Self
pub const SIGNAL_STRENGTH_EVENT: Self
Signal strength indication.
pub const CELL_ACCESS_STATE_CHG_EVENT: Self
pub const CELL_ACCESS_STATE_CHG_EVENT: Self
Cell access state change indication.
pub const NITZ_TIME_UPDATE_EVENT: Self
pub const NITZ_TIME_UPDATE_EVENT: Self
NITZ time update indication.
pub const RF_BAND_UPDATE_EVENT: Self
pub const RF_BAND_UPDATE_EVENT: Self
RF band update indication.
impl IndicationFlag
impl IndicationFlag
pub const fn empty() -> Self
pub const fn empty() -> Self
Get a flags value with all bits unset.
pub const fn all() -> Self
pub const fn all() -> Self
Get a flags value with all known bits set.
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
pub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
pub fn insert(&mut self, other: Self)
pub fn insert(&mut self, other: Self)
The bitwise or (|) of the bits in two flags values.
pub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
pub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
pub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
pub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
pub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
impl IndicationFlag
impl IndicationFlag
pub const fn iter(&self) -> Iter<IndicationFlag>
pub const fn iter(&self) -> Iter<IndicationFlag>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<IndicationFlag>
pub const fn iter_names(&self) -> IterNames<IndicationFlag>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.