Struct ScanResultListInfo
#[repr(C)]pub struct ScanResultListInfo {
pub entry_len: u32,
pub entry: [ScanEntryInfo; 40],
}Expand description
Gets the status associated with the connection of <id>.
Fields
entry_len: u32Must be set to the number of elements in entry.
entry: [ScanEntryInfo; 40]Scan entry.