Function add_rx_msg_handler
pub unsafe extern "C" fn add_rx_msg_handler(
handle: ClientHandle,
handler: RxMsgHandlerFn,
context: *mut c_void,
) -> ErrorAvailable on non-
ag35 only.Expand description
Adds a handler for receiving network events based on the provided event flag bitmask.
See event_register for more details on the event flag bitmask.
Implementation notes
This function simply writes the provided handler and context into global variables. It is NOT protected against concurrent calls, so it is not thread-safe. Calling this function multiple times will overwrite the previously registered handler and context.
Calls:
ql_log_print