Function get_reg_status
pub unsafe extern "C" fn get_reg_status(
handle: ClientHandle,
info: *mut RegStatusInfo,
) -> ErrorAvailable on non-
ag35 only.Expand description
Gets the registration status information for voice and data connections.
Implementation notes
Calls:
ql_log_printmcm_client_execute_command_sync- Request type:
mcm_nw_get_registration_status_req_msg_v01 - Response type:
mcm_nw_get_registration_status_resp_msg_v01
- Request type:
Uses a heap allocation for the mcm_nw_get_registration_status_resp_msg_v01
response before copying the data into the info parameter.